/*
 * Copyright (c) Members of the EGEE Collaboration. 2004. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
 
/*
 *
 * Authors: Paolo Andreetto, <paolo.andreetto@pd.infn.it>
 *
 */

package org.glite.ce.monitorapij.ant;

import java.io.File;
import java.io.StringReader;
import java.io.FileInputStream;
import java.io.Writer;
import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;

import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;
import javax.xml.parsers.ParserConfigurationException;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;
import org.xml.sax.InputSource;

import org.apache.axis.utils.Admin;
import org.apache.axis.utils.XMLUtils;
import org.apache.axis.AxisEngine;
import org.apache.axis.server.AxisServer;
import org.apache.axis.deployment.wsdd.WSDDDocument;
import org.apache.axis.WSDDEngineConfiguration;
import org.apache.axis.deployment.wsdd.WSDDDeployment;
import org.w3c.dom.Document;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

public class ServerConfigParserTask extends Task{

    private String source;
    private String target;
    private String service;
    private String version;

    public ServerConfigParserTask(){
    }

    public void setSource(String file){
        source = file;
    }

    public void setTarget(String file){
        target = file;
    }

    public void setService(String srv){
        service = srv;
    }

    public void setVersion(String ver){
        version = ver;
    }

    public void execute() throws BuildException {

        StringReader reader = null;
        BufferedWriter writer = null;

        try{

            WSDDFileConfiguration wsddConf = new WSDDFileConfiguration("server-config.wsdd");

            Admin admin = new Admin();
            AxisEngine engine = new AxisServer(wsddConf);
            Document doc = XMLUtils.newDocument(new FileInputStream(source));

            WSDDDocument wsddDoc = new WSDDDocument(doc);
            WSDDEngineConfiguration config = (WSDDEngineConfiguration)engine.getConfig();
            WSDDDeployment deployment = config.getDeployment();
            wsddDoc.deploy(deployment);
            engine.refreshGlobalOptions();
            engine.saveConfiguration();

            writer = new BufferedWriter(new FileWriter(target));
            ServerConfigParser parser = new ServerConfigParser(writer, service, version);

            writer.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");

            SAXParserFactory spf=SAXParserFactory.newInstance();
            spf.setValidating(false);
            SAXParser sp = spf.newSAXParser();

            reader = new StringReader(wsddConf.toString());
            InputSource input=new InputSource(reader);
            input.setSystemId("file://" + new File(source).getAbsolutePath());

            sp.parse(input,parser);

        }catch(Exception ex){
            throw new BuildException(ex.getMessage());
        }finally{
            if( writer!=null )
                try{ writer.close(); }catch(Exception ex){}
            if( reader!=null )
                try{ reader.close(); }catch(Exception ex){}
        }

    }


    public static void main(String[] args){

        if( args.length!=4 ){
            System.out.println("Bad parameter number");
            System.exit(1);
        }

        try{

            ServerConfigParserTask task = new ServerConfigParserTask();
            task.setSource(args[0]);
            task.setTarget(args[1]);
            task.setService(args[2]);
            task.setVersion(args[3]);
            task.execute();

        }catch(BuildException ex){
            System.out.println(ex.getMessage());
            System.exit(1);
        }
    }

    
}
